#
# spec file for package yp-tools
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           yp-tools
Version:        4.2.2
Release:        3.5
Summary:        Network Information Service (YP) client utilities
License:        GPL-2.0 and LGPL-2.1
Group:          Productivity/Networking/NIS
Source:         http://www.linux-nis.org/download/yp-tools/yp-tools-%{version}.tar.bz2
Url:            http://www.linux-nis.org/
BuildRequires:	fdupes
BuildRequires:  pkgconfig
%if 0%{?suse_version} >= 1310
BuildRequires:  pkgconfig(libtirpc) >= 1.0.1
BuildRequires:	pkgconfig(libnsl) >= 1.0.4
%endif
Source1:        match_printcap
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This packages contains some useful tools for accessing NIS maps or to
test NIS configurations.

%package -n libnis-devel
Summary:        NIS header files and libraries for development
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       libnis1 = %version

%description -n libnis-devel
This package contains the include files and libraries needed to
develop applications using the IPv6 ready NIS functions. This
includes support for the ypbind v3 protocol, too.

%prep
%setup -q

%build
# Work around use of bad cast
CFLAGS="%optflags -Wno-error=cast-align"
%configure --disable-static --with-pic --enable-call-passwd \
%if %{suse_version} == 1315
	--enable-domainname
%else
	--disable-domainname
%endif
make %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}%{_prefix}/lib/yp
install -m 755 %{SOURCE1} %{buildroot}%{_prefix}/lib/yp
mkdir %{buildroot}/%{_lib}
%if %{suse_version} == 1315
cp -a %{buildroot}%{_mandir}/man8/domainname.8 %{buildroot}%{_mandir}/man8/nisdomainname.8
cp -a %{buildroot}%{_mandir}/man8/domainname.8 %{buildroot}%{_mandir}/man8/ypdomainname.8
rm %{buildroot}%{_bindir}/domainname %{buildroot}%{_mandir}/man8/domainname.8
mkdir -p %{buildroot}/bin
ln -sf %{_bindir}/nisdomainname %{buildroot}/bin
ln -sf %{_bindir}/ypdomainname %{buildroot}/bin
%endif
%{find_lang} %{name}
%fdupes %buildroot/%_prefix

%files -f %{name}.lang
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README THANKS
%dir %{_localstatedir}/yp
%config(noreplace) %{_localstatedir}/yp/nicknames
%{_bindir}/ypcat
%{_bindir}/ypchfn
%{_bindir}/ypchsh
%{_bindir}/ypmatch
%{_bindir}/yppasswd
%{_bindir}/ypwhich
%dir %{_prefix}/lib/yp
%{_prefix}/lib/yp/match_printcap
%doc %{_mandir}/man1/ypcat.1.gz
%doc %{_mandir}/man1/ypchfn.1.gz
%doc %{_mandir}/man1/ypchsh.1.gz
%doc %{_mandir}/man1/ypmatch.1.gz
%doc %{_mandir}/man1/yppasswd.1.gz
%doc %{_mandir}/man1/ypwhich.1.gz
%doc %{_mandir}/man5/nicknames.5.gz
%doc %{_mandir}/man8/yppoll.8.gz
%doc %{_mandir}/man8/ypset.8.gz
%doc %{_mandir}/man8/yp_dump_binding.8.gz
%{_sbindir}/yppoll
%{_sbindir}/ypset
%{_sbindir}/yp_dump_binding
%if %{suse_version} == 1315
/bin/nisdomainname
/bin/ypdomainname
%{_bindir}/nisdomainname
%{_bindir}/ypdomainname
%doc %{_mandir}/man8/ypdomainname.8.gz
%doc %{_mandir}/man8/nisdomainname.8.gz
%endif

%changelog
* Fri Aug 19 2016 kukuk@suse.de
- Re-add ypdomainname and nisdomainname for SLE12 and Leap 42.x
  [bsc#994532]
* Wed Mar 30 2016 kukuk@suse.de
- Disable ypdomainname and nisdomainname
* Mon Mar 14 2016 kukuk@suse.de
- Update to version 4.2.2
  - revert netdb.h changes
* Mon Mar 14 2016 kukuk@suse.de
- Update to version 4.2.1
  - fix order of configure checks
* Tue Mar  8 2016 kukuk@suse.de
- Update to version 4.2
  - fix compiling with old glibc
  - fix bug in fallback code, if ypbind does not speak v3 protocol
* Wed Mar  2 2016 kukuk@suse.de
- Update to version 4.1
  - allow building only with glibc
  - fix seg.fault in yppoll
  - fix yppasswd to work with IPv6
* Tue Feb  2 2016 kukuk@suse.de
- Update to version 4.0
  - build against external libnsl2
- Drop libnis* and libnss_nis6* sub-packages
* Wed Jan 20 2016 kukuk@suse.de
- Update to version 3.5
  - modify internal interface to avoid cast errors
* Fri May  8 2015 kukuk@suse.de
- Update to version 3.4
  - remove some glibc special macros not working on SLES11
- Require libtirpc >= 0.3.0
* Thu Mar 26 2015 kukuk@suse.de
- Revert changes from Dec 4th and 6th, most of them were wrong.
- Update to version 3.3:
  - fix some linking issues
  - add yp_dump_binding
  - Fix file descriptor leak in libnis
  - Fix wrong fallback for binding files in libnis
  - Fix link order
  - Implement locking for multithreaded applications
* Wed Dec 17 2014 schwab@suse.de
- Avoid error from bad cast
* Sat Dec  6 2014 jengelh@inai.de
- Corrections to the description
* Thu Dec  4 2014 jengelh@inai.de
- Reduce filelists by using wildcards. Remove %%doc (it is implicit
  for documentation paths).
- Run build in parallel, and run fdupes to reduce same files.
* Thu Nov 27 2014 dimstar@opensuse.org
- Filter libc.so.6(GLIBC_PRIVATE) from the requires of libnss_nis6:
  we consciously use glibc internas.
- Do not install libtool archives.
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix bashism in match_printcap script
* Mon Nov  3 2014 kukuk@suse.de
- Update to version 3.0.1
  - Use very short timeout for clnt_create()
* Mon Nov  3 2014 kukuk@suse.de
- Update to version 3.0
  - fix xdrfile-test.c on 32bit
* Fri Oct 31 2014 kukuk@suse.de
- Update to version 2.99.8
  - Enhance libnis for ypserv
* Thu Oct 30 2014 kukuk@suse.de
- Update to version 2.99.7
  - Rework nss_nis6 dependencys
    (RPM handles glibc provides very special)
  - Some fixes to yp_prot.h for ypserv
* Wed Oct 29 2014 kukuk@suse.de
- Update to version 2.99.6
  - Finish libnis library
  - Add nss_nis6 plugin for glibc
* Tue Oct 28 2014 kukuk@suse.de
- Update to version 2.99.5
  - Implement v3 protocol for ypset
  - Enhance libnis library
* Sat Oct 25 2014 kukuk@suse.de
- Update to version 2.99.4
  - fixes last IPv4 only code (except ypset)
* Fri Oct 24 2014 kukuk@suse.de
- Update to version 2.99.3
  - fixes some bugs to build ypbind
* Fri Oct 24 2014 kukuk@suse.de
- Update to version 2.99.2
  - ypwhich speaks now ypbind v3 protocol
  - Add seperate libnis library
* Tue Oct 21 2014 kukuk@suse.de
- Update to version 2.99.1
  - port to TI-RPC
  - ypwhich and ypset can now use IPv6 to speak with ypbind
* Tue Apr  9 2013 kukuk@suse.de
- Update to version 2.14 (minor bugfix release)
* Mon Apr  8 2013 kukuk@suse.de
- Update to version 2.13 (autoconf meta data update)
* Fri Apr  5 2013 idonmez@suse.com
- Cleanup spec file
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Sat Feb  4 2012 rschweikert@suse.com
- keep all binaries in /usr (UsrMerge project)
* Wed May 11 2011 kukuk@suse.de
- Don't build against libxcrypt (not necessary).
* Wed Apr 21 2010 kukuk@suse.de
- Update to 2.12: Documentation fixes, fix detection of passwd, chsh
  and chfn.
* Tue Apr 20 2010 kukuk@suse.de
- Update to latest upstream version
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 schwab@suse.de
- Don't strip binaries.
* Mon Jun 21 2004 kukuk@suse.de
- Update to 2.9 (minor documentation and bug fixes)
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Wed Jun 11 2003 kukuk@suse.de
- Use %%find_lang
* Thu May 15 2003 kukuk@suse.de
- Add hint about programs, which cache the domainname, to the
  manual page of domainname. [Bug #18975]
* Fri Jan 17 2003 kukuk@suse.de
- Update to version 2.8 (includes all extra patches)
* Thu Aug 29 2002 kukuk@suse.de
- Make sure strings are NUL terminated after strncpy
* Mon May 27 2002 kukuk@suse.de
- Apply fixes for typos
* Mon May 13 2002 kukuk@suse.de
- Update to yp-tools 2.7 (Add yptest, improve options of ypcat)
- Use libxcrypt
* Wed Oct 31 2001 kukuk@suse.de
- Update to yp-tools 2.6 (fixed setlocale calls)
* Sun Apr 15 2001 schwab@suse.de
- Fix missing declarations.
* Thu Apr 12 2001 kukuk@suse.de
- Change patch and configure call for new gettext version
* Thu Mar 22 2001 ro@suse.de
- added split-aliases as provides
* Wed Mar 21 2001 kukuk@suse.de
- Update to 2.5
* Thu Nov  2 2000 kukuk@suse.de
- New, split from old ypclients package
